@@ -2,7 +2,7 @@
 
 namespace WebThumbnailer\Utils;
 
-use PHPUnit\Framework\TestCase;
+use WebThumbnailer\TestCase;
 
 /**
  * Class DataUtilsTest
@@ -31,7 +31,7 @@ class DataUtilsTest extends TestCase
     {
         $this->expectException(\Exception::class);
         $this->expectExceptionMessageRegExp('/An error occured while parsing JSON file: error code #/');
-        $path = __DIR__ . DIRECTORY_SEPARATOR . '..'. DIRECTORY_SEPARATOR . 'resources' . DIRECTORY_SEPARATOR;
+        $path = __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'resources' . DIRECTORY_SEPARATOR;
         DataUtils::loadJson($path . 'badsyntax.json');
     }
 }
